:mod:`stix.exploit_target.configuration` Module
===============================================

.. module:: stix.exploit_target.configuration

Overview
--------
The :mod:`stix.exploit_target.configuration` module captures the software configuration that causes a vulnerability in a system. 


Classes
-------

.. autoclass:: Configuration
	:show-inheritance:
	:members:
